Class: Aws::LambdaMicrovms::Types::CodeArtifact

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-lambdamicrovms/types.rb

Overview

Note:

CodeArtifact is a union - when making an API calls you must set exactly one of the members.

Note:

CodeArtifact is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of CodeArtifact corresponding to the set member.

Contains the location of the code artifact for a MicroVM image.

Direct Known Subclasses

Unknown, Uri

Defined Under Namespace

Classes: Unknown, Uri

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



58
59
60
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 58

def unknown
  @unknown
end

#uriString

The URI of the code artifact, such as an Amazon S3 path or Amazon ECR image URI.

Returns:

  • (String)


58
59
60
61
62
63
64
65
66
67
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 58

class CodeArtifact < Struct.new(
  :uri,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Uri < CodeArtifact; end
  class Unknown < CodeArtifact; end
end