Class: Aws::LambdaMicrovms::Types::CreateMicrovmAuthTokenRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambdamicrovms/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_portsArray<Types::PortSpecification>

The list of port specifications that the authentication token grants access to on the MicroVM.

Returns:



123
124
125
126
127
128
129
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 123

class CreateMicrovmAuthTokenRequest < Struct.new(
  :microvm_identifier,
  :expiration_in_minutes,
  :allowed_ports)
  SENSITIVE = []
  include Aws::Structure
end

#expiration_in_minutesInteger

The duration in minutes before the authentication token expires. Maximum: 60 minutes.

Returns:

  • (Integer)


123
124
125
126
127
128
129
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 123

class CreateMicrovmAuthTokenRequest < Struct.new(
  :microvm_identifier,
  :expiration_in_minutes,
  :allowed_ports)
  SENSITIVE = []
  include Aws::Structure
end

#microvm_identifierString

The ID of the MicroVM to create an authentication token for.

Returns:

  • (String)


123
124
125
126
127
128
129
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 123

class CreateMicrovmAuthTokenRequest < Struct.new(
  :microvm_identifier,
  :expiration_in_minutes,
  :allowed_ports)
  SENSITIVE = []
  include Aws::Structure
end