Class: Aws::LambdaMicrovms::Types::CreateMicrovmImageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LambdaMicrovms::Types::CreateMicrovmImageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambdamicrovms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_os_capabilities ⇒ Array<String>
Additional OS capabilities granted to the MicroVM runtime environment.
-
#base_image_arn ⇒ String
The ARN of the Lambda-managed base MicroVM image to build upon.
-
#base_image_version ⇒ String
The specific version of the base MicroVM image to use.
-
#build_role_arn ⇒ String
The ARN of the IAM role assumed during the image build process.
-
#client_token ⇒ String
A unique, case-sensitive identifier you provide to ensure the idempotency of the request.
-
#code_artifact ⇒ Types::CodeArtifact
The code artifact containing the application code and metadata for the MicroVM image.
-
#cpu_configurations ⇒ Array<Types::CpuConfiguration>
The list of supported CPU configurations for the MicroVM.
-
#description ⇒ String
A description of the MicroVM image.
-
#egress_network_connectors ⇒ Array<String>
The list of egress network connectors available to the MicroVM at runtime.
-
#environment_variables ⇒ Hash<String,String>
Environment variables set in the MicroVM runtime environment.
-
#hooks ⇒ Types::Hooks
Lifecycle hook configuration for MicroVMs and MicroVM images.
-
#logging ⇒ Types::Logging
The logging configuration for build-time and runtime logs.
-
#name ⇒ String
The name of the MicroVM image.
-
#resources ⇒ Array<Types::Resources>
The resource requirements for the MicroVM.
-
#tags ⇒ Hash<String,String>
A set of key-value pairs that you can attach to the resource.
Instance Attribute Details
#additional_os_capabilities ⇒ Array<String>
Additional OS capabilities granted to the MicroVM runtime environment.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 225 class CreateMicrovmImageRequest < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :name, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#base_image_arn ⇒ String
The ARN of the Lambda-managed base MicroVM image to build upon. Use ListManagedMicrovmImages to discover available base images.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 225 class CreateMicrovmImageRequest < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :name, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#base_image_version ⇒ String
The specific version of the base MicroVM image to use.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 225 class CreateMicrovmImageRequest < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :name, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#build_role_arn ⇒ String
The ARN of the IAM role assumed during the image build process. This role must have permissions to access the code artifact and any required resources.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 225 class CreateMicrovmImageRequest < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :name, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier you provide to ensure the idempotency of the request. If you retry a request that completed successfully using the same client token, the operation returns the successful response without performing any further actions.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 225 class CreateMicrovmImageRequest < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :name, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#code_artifact ⇒ Types::CodeArtifact
The code artifact containing the application code and metadata for the MicroVM image.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 225 class CreateMicrovmImageRequest < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :name, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#cpu_configurations ⇒ Array<Types::CpuConfiguration>
The list of supported CPU configurations for the MicroVM.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 225 class CreateMicrovmImageRequest < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :name, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the MicroVM image.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 225 class CreateMicrovmImageRequest < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :name, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#egress_network_connectors ⇒ Array<String>
The list of egress network connectors available to the MicroVM at runtime.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 225 class CreateMicrovmImageRequest < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :name, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#environment_variables ⇒ Hash<String,String>
Environment variables set in the MicroVM runtime environment.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 225 class CreateMicrovmImageRequest < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :name, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#hooks ⇒ Types::Hooks
Lifecycle hook configuration for MicroVMs and MicroVM images.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 225 class CreateMicrovmImageRequest < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :name, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#logging ⇒ Types::Logging
The logging configuration for build-time and runtime logs. Specify {“logGroup”: “…”} to stream logs to a custom CloudWatch log group, or {} to turn off logging.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 225 class CreateMicrovmImageRequest < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :name, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the MicroVM image. Must be unique within the AWS account.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 225 class CreateMicrovmImageRequest < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :name, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#resources ⇒ Array<Types::Resources>
The resource requirements for the MicroVM.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 225 class CreateMicrovmImageRequest < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :name, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A set of key-value pairs that you can attach to the resource. Use tags to categorize resources for cost allocation, access control (ABAC), and organization.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 225 class CreateMicrovmImageRequest < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :name, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |