Class: Aws::LambdaMicrovms::Types::CreateMicrovmImageResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambdamicrovms/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_os_capabilitiesArray<String>

Additional OS capabilities granted to the MicroVM runtime environment.

Returns:

  • (Array<String>)


339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 339

class CreateMicrovmImageResponse < Struct.new(
  :image_arn,
  :name,
  :state,
  :latest_active_image_version,
  :latest_failed_image_version,
  :created_at,
  :base_image_arn,
  :base_image_version,
  :build_role_arn,
  :description,
  :code_artifact,
  :logging,
  :egress_network_connectors,
  :cpu_configurations,
  :resources,
  :additional_os_capabilities,
  :hooks,
  :environment_variables,
  :tags,
  :updated_at,
  :image_version)
  SENSITIVE = []
  include Aws::Structure
end

#base_image_arnString

The ARN of the base MicroVM image.

Returns:

  • (String)


339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 339

class CreateMicrovmImageResponse < Struct.new(
  :image_arn,
  :name,
  :state,
  :latest_active_image_version,
  :latest_failed_image_version,
  :created_at,
  :base_image_arn,
  :base_image_version,
  :build_role_arn,
  :description,
  :code_artifact,
  :logging,
  :egress_network_connectors,
  :cpu_configurations,
  :resources,
  :additional_os_capabilities,
  :hooks,
  :environment_variables,
  :tags,
  :updated_at,
  :image_version)
  SENSITIVE = []
  include Aws::Structure
end

#base_image_versionString

The specific version of the base MicroVM image.

Returns:

  • (String)


339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 339

class CreateMicrovmImageResponse < Struct.new(
  :image_arn,
  :name,
  :state,
  :latest_active_image_version,
  :latest_failed_image_version,
  :created_at,
  :base_image_arn,
  :base_image_version,
  :build_role_arn,
  :description,
  :code_artifact,
  :logging,
  :egress_network_connectors,
  :cpu_configurations,
  :resources,
  :additional_os_capabilities,
  :hooks,
  :environment_variables,
  :tags,
  :updated_at,
  :image_version)
  SENSITIVE = []
  include Aws::Structure
end

#build_role_arnString

The ARN of the IAM build role.

Returns:

  • (String)


339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 339

class CreateMicrovmImageResponse < Struct.new(
  :image_arn,
  :name,
  :state,
  :latest_active_image_version,
  :latest_failed_image_version,
  :created_at,
  :base_image_arn,
  :base_image_version,
  :build_role_arn,
  :description,
  :code_artifact,
  :logging,
  :egress_network_connectors,
  :cpu_configurations,
  :resources,
  :additional_os_capabilities,
  :hooks,
  :environment_variables,
  :tags,
  :updated_at,
  :image_version)
  SENSITIVE = []
  include Aws::Structure
end

#code_artifactTypes::CodeArtifact

The code artifact containing the application code and metadata for the MicroVM image.

Returns:



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 339

class CreateMicrovmImageResponse < Struct.new(
  :image_arn,
  :name,
  :state,
  :latest_active_image_version,
  :latest_failed_image_version,
  :created_at,
  :base_image_arn,
  :base_image_version,
  :build_role_arn,
  :description,
  :code_artifact,
  :logging,
  :egress_network_connectors,
  :cpu_configurations,
  :resources,
  :additional_os_capabilities,
  :hooks,
  :environment_variables,
  :tags,
  :updated_at,
  :image_version)
  SENSITIVE = []
  include Aws::Structure
end

#cpu_configurationsArray<Types::CpuConfiguration>

The list of supported CPU configurations for the MicroVM.

Returns:



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 339

class CreateMicrovmImageResponse < Struct.new(
  :image_arn,
  :name,
  :state,
  :latest_active_image_version,
  :latest_failed_image_version,
  :created_at,
  :base_image_arn,
  :base_image_version,
  :build_role_arn,
  :description,
  :code_artifact,
  :logging,
  :egress_network_connectors,
  :cpu_configurations,
  :resources,
  :additional_os_capabilities,
  :hooks,
  :environment_variables,
  :tags,
  :updated_at,
  :image_version)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The timestamp when the MicroVM image was created.

Returns:

  • (Time)


339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 339

class CreateMicrovmImageResponse < Struct.new(
  :image_arn,
  :name,
  :state,
  :latest_active_image_version,
  :latest_failed_image_version,
  :created_at,
  :base_image_arn,
  :base_image_version,
  :build_role_arn,
  :description,
  :code_artifact,
  :logging,
  :egress_network_connectors,
  :cpu_configurations,
  :resources,
  :additional_os_capabilities,
  :hooks,
  :environment_variables,
  :tags,
  :updated_at,
  :image_version)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the MicroVM image.

Returns:

  • (String)


339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 339

class CreateMicrovmImageResponse < Struct.new(
  :image_arn,
  :name,
  :state,
  :latest_active_image_version,
  :latest_failed_image_version,
  :created_at,
  :base_image_arn,
  :base_image_version,
  :build_role_arn,
  :description,
  :code_artifact,
  :logging,
  :egress_network_connectors,
  :cpu_configurations,
  :resources,
  :additional_os_capabilities,
  :hooks,
  :environment_variables,
  :tags,
  :updated_at,
  :image_version)
  SENSITIVE = []
  include Aws::Structure
end

#egress_network_connectorsArray<String>

The list of egress network connectors available to the MicroVM at runtime.

Returns:

  • (Array<String>)


339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 339

class CreateMicrovmImageResponse < Struct.new(
  :image_arn,
  :name,
  :state,
  :latest_active_image_version,
  :latest_failed_image_version,
  :created_at,
  :base_image_arn,
  :base_image_version,
  :build_role_arn,
  :description,
  :code_artifact,
  :logging,
  :egress_network_connectors,
  :cpu_configurations,
  :resources,
  :additional_os_capabilities,
  :hooks,
  :environment_variables,
  :tags,
  :updated_at,
  :image_version)
  SENSITIVE = []
  include Aws::Structure
end

#environment_variablesHash<String,String>

Environment variables set in the MicroVM runtime environment.

Returns:

  • (Hash<String,String>)


339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 339

class CreateMicrovmImageResponse < Struct.new(
  :image_arn,
  :name,
  :state,
  :latest_active_image_version,
  :latest_failed_image_version,
  :created_at,
  :base_image_arn,
  :base_image_version,
  :build_role_arn,
  :description,
  :code_artifact,
  :logging,
  :egress_network_connectors,
  :cpu_configurations,
  :resources,
  :additional_os_capabilities,
  :hooks,
  :environment_variables,
  :tags,
  :updated_at,
  :image_version)
  SENSITIVE = []
  include Aws::Structure
end

#hooksTypes::Hooks

Lifecycle hook configuration for MicroVMs and MicroVM images.

Returns:



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 339

class CreateMicrovmImageResponse < Struct.new(
  :image_arn,
  :name,
  :state,
  :latest_active_image_version,
  :latest_failed_image_version,
  :created_at,
  :base_image_arn,
  :base_image_version,
  :build_role_arn,
  :description,
  :code_artifact,
  :logging,
  :egress_network_connectors,
  :cpu_configurations,
  :resources,
  :additional_os_capabilities,
  :hooks,
  :environment_variables,
  :tags,
  :updated_at,
  :image_version)
  SENSITIVE = []
  include Aws::Structure
end

#image_arnString

The ARN of the created MicroVM image.

Returns:

  • (String)


339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 339

class CreateMicrovmImageResponse < Struct.new(
  :image_arn,
  :name,
  :state,
  :latest_active_image_version,
  :latest_failed_image_version,
  :created_at,
  :base_image_arn,
  :base_image_version,
  :build_role_arn,
  :description,
  :code_artifact,
  :logging,
  :egress_network_connectors,
  :cpu_configurations,
  :resources,
  :additional_os_capabilities,
  :hooks,
  :environment_variables,
  :tags,
  :updated_at,
  :image_version)
  SENSITIVE = []
  include Aws::Structure
end

#image_versionString

The version of the MicroVM image.

Returns:

  • (String)


339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 339

class CreateMicrovmImageResponse < Struct.new(
  :image_arn,
  :name,
  :state,
  :latest_active_image_version,
  :latest_failed_image_version,
  :created_at,
  :base_image_arn,
  :base_image_version,
  :build_role_arn,
  :description,
  :code_artifact,
  :logging,
  :egress_network_connectors,
  :cpu_configurations,
  :resources,
  :additional_os_capabilities,
  :hooks,
  :environment_variables,
  :tags,
  :updated_at,
  :image_version)
  SENSITIVE = []
  include Aws::Structure
end

#latest_active_image_versionString

The latest active version of the MicroVM image.

Returns:

  • (String)


339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 339

class CreateMicrovmImageResponse < Struct.new(
  :image_arn,
  :name,
  :state,
  :latest_active_image_version,
  :latest_failed_image_version,
  :created_at,
  :base_image_arn,
  :base_image_version,
  :build_role_arn,
  :description,
  :code_artifact,
  :logging,
  :egress_network_connectors,
  :cpu_configurations,
  :resources,
  :additional_os_capabilities,
  :hooks,
  :environment_variables,
  :tags,
  :updated_at,
  :image_version)
  SENSITIVE = []
  include Aws::Structure
end

#latest_failed_image_versionString

The latest failed version of the MicroVM image, if any.

Returns:

  • (String)


339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 339

class CreateMicrovmImageResponse < Struct.new(
  :image_arn,
  :name,
  :state,
  :latest_active_image_version,
  :latest_failed_image_version,
  :created_at,
  :base_image_arn,
  :base_image_version,
  :build_role_arn,
  :description,
  :code_artifact,
  :logging,
  :egress_network_connectors,
  :cpu_configurations,
  :resources,
  :additional_os_capabilities,
  :hooks,
  :environment_variables,
  :tags,
  :updated_at,
  :image_version)
  SENSITIVE = []
  include Aws::Structure
end

#loggingTypes::Logging

The logging configuration for build-time and runtime logs. Specify {“logGroup”: “…”} to stream logs to a custom CloudWatch log group, or {} to turn off logging.

Returns:



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 339

class CreateMicrovmImageResponse < Struct.new(
  :image_arn,
  :name,
  :state,
  :latest_active_image_version,
  :latest_failed_image_version,
  :created_at,
  :base_image_arn,
  :base_image_version,
  :build_role_arn,
  :description,
  :code_artifact,
  :logging,
  :egress_network_connectors,
  :cpu_configurations,
  :resources,
  :additional_os_capabilities,
  :hooks,
  :environment_variables,
  :tags,
  :updated_at,
  :image_version)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the MicroVM image.

Returns:

  • (String)


339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 339

class CreateMicrovmImageResponse < Struct.new(
  :image_arn,
  :name,
  :state,
  :latest_active_image_version,
  :latest_failed_image_version,
  :created_at,
  :base_image_arn,
  :base_image_version,
  :build_role_arn,
  :description,
  :code_artifact,
  :logging,
  :egress_network_connectors,
  :cpu_configurations,
  :resources,
  :additional_os_capabilities,
  :hooks,
  :environment_variables,
  :tags,
  :updated_at,
  :image_version)
  SENSITIVE = []
  include Aws::Structure
end

#resourcesArray<Types::Resources>

The resource requirements for the MicroVM.

Returns:



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 339

class CreateMicrovmImageResponse < Struct.new(
  :image_arn,
  :name,
  :state,
  :latest_active_image_version,
  :latest_failed_image_version,
  :created_at,
  :base_image_arn,
  :base_image_version,
  :build_role_arn,
  :description,
  :code_artifact,
  :logging,
  :egress_network_connectors,
  :cpu_configurations,
  :resources,
  :additional_os_capabilities,
  :hooks,
  :environment_variables,
  :tags,
  :updated_at,
  :image_version)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The current state of the MicroVM image.

Returns:

  • (String)


339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 339

class CreateMicrovmImageResponse < Struct.new(
  :image_arn,
  :name,
  :state,
  :latest_active_image_version,
  :latest_failed_image_version,
  :created_at,
  :base_image_arn,
  :base_image_version,
  :build_role_arn,
  :description,
  :code_artifact,
  :logging,
  :egress_network_connectors,
  :cpu_configurations,
  :resources,
  :additional_os_capabilities,
  :hooks,
  :environment_variables,
  :tags,
  :updated_at,
  :image_version)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

A set of key-value pairs that you can attach to the resource. Use tags to categorize resources for cost allocation, access control (ABAC), and organization.

Returns:

  • (Hash<String,String>)


339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 339

class CreateMicrovmImageResponse < Struct.new(
  :image_arn,
  :name,
  :state,
  :latest_active_image_version,
  :latest_failed_image_version,
  :created_at,
  :base_image_arn,
  :base_image_version,
  :build_role_arn,
  :description,
  :code_artifact,
  :logging,
  :egress_network_connectors,
  :cpu_configurations,
  :resources,
  :additional_os_capabilities,
  :hooks,
  :environment_variables,
  :tags,
  :updated_at,
  :image_version)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The timestamp when the MicroVM image was last updated.

Returns:

  • (Time)


339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 339

class CreateMicrovmImageResponse < Struct.new(
  :image_arn,
  :name,
  :state,
  :latest_active_image_version,
  :latest_failed_image_version,
  :created_at,
  :base_image_arn,
  :base_image_version,
  :build_role_arn,
  :description,
  :code_artifact,
  :logging,
  :egress_network_connectors,
  :cpu_configurations,
  :resources,
  :additional_os_capabilities,
  :hooks,
  :environment_variables,
  :tags,
  :updated_at,
  :image_version)
  SENSITIVE = []
  include Aws::Structure
end