Class: Aws::LambdaMicrovms::Types::CreateMicrovmShellAuthTokenRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LambdaMicrovms::Types::CreateMicrovmShellAuthTokenRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambdamicrovms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#expiration_in_minutes ⇒ Integer
The duration in minutes before the shell authentication token expires.
-
#microvm_identifier ⇒ String
The ID of the MicroVM to create a shell authentication token for.
Instance Attribute Details
#expiration_in_minutes ⇒ Integer
The duration in minutes before the shell authentication token expires.
376 377 378 379 380 381 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 376 class CreateMicrovmShellAuthTokenRequest < Struct.new( :microvm_identifier, :expiration_in_minutes) SENSITIVE = [] include Aws::Structure end |
#microvm_identifier ⇒ String
The ID of the MicroVM to create a shell authentication token for.
376 377 378 379 380 381 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 376 class CreateMicrovmShellAuthTokenRequest < Struct.new( :microvm_identifier, :expiration_in_minutes) SENSITIVE = [] include Aws::Structure end |