Class: Aws::LambdaMicrovms::Types::GetMicrovmImageBuildOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::LambdaMicrovms::Types::GetMicrovmImageBuildOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambdamicrovms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#architecture ⇒ String
The target CPU architecture for the build.
-
#build_id ⇒ String
The build request ID.
-
#build_state ⇒ String
The current state of the build.
-
#chipset ⇒ String
The target chipset for the build.
-
#chipset_generation ⇒ String
The target chipset generation for the build.
-
#created_at ⇒ Time
The timestamp when the build was created.
-
#image_arn ⇒ String
The ARN of the MicroVM image.
-
#image_version ⇒ String
The version of the MicroVM image.
-
#snapshot_build ⇒ Types::SnapshotBuild
The snapshot build details, including memory and disk snapshot sizes.
-
#state_reason ⇒ String
The reason for the build state, if applicable.
Instance Attribute Details
#architecture ⇒ String
The target CPU architecture for the build. Supported value: ARM_64.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 529 class GetMicrovmImageBuildOutput < Struct.new( :image_arn, :image_version, :build_id, :build_state, :architecture, :chipset, :chipset_generation, :state_reason, :created_at, :snapshot_build) SENSITIVE = [] include Aws::Structure end |
#build_id ⇒ String
The build request ID.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 529 class GetMicrovmImageBuildOutput < Struct.new( :image_arn, :image_version, :build_id, :build_state, :architecture, :chipset, :chipset_generation, :state_reason, :created_at, :snapshot_build) SENSITIVE = [] include Aws::Structure end |
#build_state ⇒ String
The current state of the build.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 529 class GetMicrovmImageBuildOutput < Struct.new( :image_arn, :image_version, :build_id, :build_state, :architecture, :chipset, :chipset_generation, :state_reason, :created_at, :snapshot_build) SENSITIVE = [] include Aws::Structure end |
#chipset ⇒ String
The target chipset for the build.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 529 class GetMicrovmImageBuildOutput < Struct.new( :image_arn, :image_version, :build_id, :build_state, :architecture, :chipset, :chipset_generation, :state_reason, :created_at, :snapshot_build) SENSITIVE = [] include Aws::Structure end |
#chipset_generation ⇒ String
The target chipset generation for the build.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 529 class GetMicrovmImageBuildOutput < Struct.new( :image_arn, :image_version, :build_id, :build_state, :architecture, :chipset, :chipset_generation, :state_reason, :created_at, :snapshot_build) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when the build was created.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 529 class GetMicrovmImageBuildOutput < Struct.new( :image_arn, :image_version, :build_id, :build_state, :architecture, :chipset, :chipset_generation, :state_reason, :created_at, :snapshot_build) SENSITIVE = [] include Aws::Structure end |
#image_arn ⇒ String
The ARN of the MicroVM image.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 529 class GetMicrovmImageBuildOutput < Struct.new( :image_arn, :image_version, :build_id, :build_state, :architecture, :chipset, :chipset_generation, :state_reason, :created_at, :snapshot_build) SENSITIVE = [] include Aws::Structure end |
#image_version ⇒ String
The version of the MicroVM image.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 529 class GetMicrovmImageBuildOutput < Struct.new( :image_arn, :image_version, :build_id, :build_state, :architecture, :chipset, :chipset_generation, :state_reason, :created_at, :snapshot_build) SENSITIVE = [] include Aws::Structure end |
#snapshot_build ⇒ Types::SnapshotBuild
The snapshot build details, including memory and disk snapshot sizes.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 529 class GetMicrovmImageBuildOutput < Struct.new( :image_arn, :image_version, :build_id, :build_state, :architecture, :chipset, :chipset_generation, :state_reason, :created_at, :snapshot_build) SENSITIVE = [] include Aws::Structure end |
#state_reason ⇒ String
The reason for the build state, if applicable.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 529 class GetMicrovmImageBuildOutput < Struct.new( :image_arn, :image_version, :build_id, :build_state, :architecture, :chipset, :chipset_generation, :state_reason, :created_at, :snapshot_build) SENSITIVE = [] include Aws::Structure end |