Class: Aws::LambdaMicrovms::Types::GetMicrovmImageOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambdamicrovms/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp when the MicroVM image was created.

Returns:

  • (Time)


592
593
594
595
596
597
598
599
600
601
602
603
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 592

class GetMicrovmImageOutput < Struct.new(
  :image_arn,
  :name,
  :state,
  :latest_active_image_version,
  :latest_failed_image_version,
  :created_at,
  :tags,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#image_arnString

The ARN of the MicroVM image.

Returns:

  • (String)


592
593
594
595
596
597
598
599
600
601
602
603
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 592

class GetMicrovmImageOutput < Struct.new(
  :image_arn,
  :name,
  :state,
  :latest_active_image_version,
  :latest_failed_image_version,
  :created_at,
  :tags,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#latest_active_image_versionString

The latest active version of the MicroVM image.

Returns:

  • (String)


592
593
594
595
596
597
598
599
600
601
602
603
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 592

class GetMicrovmImageOutput < Struct.new(
  :image_arn,
  :name,
  :state,
  :latest_active_image_version,
  :latest_failed_image_version,
  :created_at,
  :tags,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#latest_failed_image_versionString

The latest failed version of the MicroVM image, if any.

Returns:

  • (String)


592
593
594
595
596
597
598
599
600
601
602
603
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 592

class GetMicrovmImageOutput < Struct.new(
  :image_arn,
  :name,
  :state,
  :latest_active_image_version,
  :latest_failed_image_version,
  :created_at,
  :tags,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the MicroVM image.

Returns:

  • (String)


592
593
594
595
596
597
598
599
600
601
602
603
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 592

class GetMicrovmImageOutput < Struct.new(
  :image_arn,
  :name,
  :state,
  :latest_active_image_version,
  :latest_failed_image_version,
  :created_at,
  :tags,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The current state of the MicroVM image.

Returns:

  • (String)


592
593
594
595
596
597
598
599
600
601
602
603
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 592

class GetMicrovmImageOutput < Struct.new(
  :image_arn,
  :name,
  :state,
  :latest_active_image_version,
  :latest_failed_image_version,
  :created_at,
  :tags,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

A set of key-value pairs that you can attach to the resource. Use tags to categorize resources for cost allocation, access control (ABAC), and organization.

Returns:

  • (Hash<String,String>)


592
593
594
595
596
597
598
599
600
601
602
603
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 592

class GetMicrovmImageOutput < Struct.new(
  :image_arn,
  :name,
  :state,
  :latest_active_image_version,
  :latest_failed_image_version,
  :created_at,
  :tags,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The timestamp when the MicroVM image was last updated.

Returns:

  • (Time)


592
593
594
595
596
597
598
599
600
601
602
603
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 592

class GetMicrovmImageOutput < Struct.new(
  :image_arn,
  :name,
  :state,
  :latest_active_image_version,
  :latest_failed_image_version,
  :created_at,
  :tags,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end