Class: Aws::LambdaMicrovms::Types::GetMicrovmImageVersionOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::LambdaMicrovms::Types::GetMicrovmImageVersionOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambdamicrovms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_os_capabilities ⇒ Array<String>
Additional OS capabilities granted to the MicroVM runtime environment.
-
#base_image_arn ⇒ String
The ARN of the base MicroVM image used.
-
#base_image_version ⇒ String
The specific version of the base MicroVM image.
-
#build_role_arn ⇒ String
The ARN of the IAM build role.
-
#code_artifact ⇒ Types::CodeArtifact
The code artifact for this version.
-
#cpu_configurations ⇒ Array<Types::CpuConfiguration>
The list of supported CPU configurations for the MicroVM.
-
#created_at ⇒ Time
The timestamp when the version was created.
-
#description ⇒ String
The description of the version.
-
#egress_network_connectors ⇒ Array<String>
The list of egress network connectors available to the MicroVM at runtime.
-
#environment_variables ⇒ Hash<String,String>
Environment variables set in the MicroVM runtime environment.
-
#hooks ⇒ Types::Hooks
Lifecycle hook configuration for MicroVMs and MicroVM images.
-
#image_arn ⇒ String
The ARN of the MicroVM image.
-
#image_version ⇒ String
The version of the MicroVM image.
-
#logging ⇒ Types::Logging
The logging configuration for this version.
-
#resources ⇒ Array<Types::Resources>
The resource requirements for the MicroVM.
-
#state ⇒ String
The current state of the version.
-
#state_reason ⇒ String
The reason for the current state.
-
#status ⇒ String
The availability status of the version: ACTIVE (can be used by RunMicrovm) or INACTIVE (blocked from launching new MicroVMs).
-
#tags ⇒ Hash<String,String>
Key-value pairs associated with the version.
-
#updated_at ⇒ Time
The timestamp when the version was last updated.
Instance Attribute Details
#additional_os_capabilities ⇒ Array<String>
Additional OS capabilities granted to the MicroVM runtime environment.
708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 708 class GetMicrovmImageVersionOutput < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#base_image_arn ⇒ String
The ARN of the base MicroVM image used.
708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 708 class GetMicrovmImageVersionOutput < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#base_image_version ⇒ String
The specific version of the base MicroVM image.
708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 708 class GetMicrovmImageVersionOutput < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#build_role_arn ⇒ String
The ARN of the IAM build role.
708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 708 class GetMicrovmImageVersionOutput < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#code_artifact ⇒ Types::CodeArtifact
The code artifact for this version.
708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 708 class GetMicrovmImageVersionOutput < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#cpu_configurations ⇒ Array<Types::CpuConfiguration>
The list of supported CPU configurations for the MicroVM.
708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 708 class GetMicrovmImageVersionOutput < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when the version was created.
708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 708 class GetMicrovmImageVersionOutput < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the version.
708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 708 class GetMicrovmImageVersionOutput < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#egress_network_connectors ⇒ Array<String>
The list of egress network connectors available to the MicroVM at runtime.
708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 708 class GetMicrovmImageVersionOutput < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#environment_variables ⇒ Hash<String,String>
Environment variables set in the MicroVM runtime environment.
708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 708 class GetMicrovmImageVersionOutput < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#hooks ⇒ Types::Hooks
Lifecycle hook configuration for MicroVMs and MicroVM images.
708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 708 class GetMicrovmImageVersionOutput < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#image_arn ⇒ String
The ARN of the MicroVM image.
708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 708 class GetMicrovmImageVersionOutput < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#image_version ⇒ String
The version of the MicroVM image.
708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 708 class GetMicrovmImageVersionOutput < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#logging ⇒ Types::Logging
The logging configuration for this version.
708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 708 class GetMicrovmImageVersionOutput < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#resources ⇒ Array<Types::Resources>
The resource requirements for the MicroVM.
708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 708 class GetMicrovmImageVersionOutput < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the version.
708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 708 class GetMicrovmImageVersionOutput < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#state_reason ⇒ String
The reason for the current state. For example, one or more builds failed.
708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 708 class GetMicrovmImageVersionOutput < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The availability status of the version: ACTIVE (can be used by RunMicrovm) or INACTIVE (blocked from launching new MicroVMs).
708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 708 class GetMicrovmImageVersionOutput < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Key-value pairs associated with the version.
708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 708 class GetMicrovmImageVersionOutput < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp when the version was last updated.
708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 708 class GetMicrovmImageVersionOutput < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |