Class: Aws::LambdaMicrovms::Types::GetMicrovmResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambdamicrovms/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#egress_network_connectorsArray<String>

The list of egress network connectors configured for the MicroVM.

Returns:

  • (Array<String>)


803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 803

class GetMicrovmResponse < Struct.new(
  :microvm_id,
  :state,
  :endpoint,
  :image_arn,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :maximum_duration_in_seconds,
  :started_at,
  :terminated_at,
  :state_reason,
  :ingress_network_connectors,
  :egress_network_connectors)
  SENSITIVE = []
  include Aws::Structure
end

#endpointString

The HTTPS endpoint URL for communicating with the MicroVM. Include a valid authentication token in the X-aws-proxy-auth header when sending requests.

Returns:

  • (String)


803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 803

class GetMicrovmResponse < Struct.new(
  :microvm_id,
  :state,
  :endpoint,
  :image_arn,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :maximum_duration_in_seconds,
  :started_at,
  :terminated_at,
  :state_reason,
  :ingress_network_connectors,
  :egress_network_connectors)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role_arnString

The ARN of the IAM execution role assumed by the MicroVM.

Returns:

  • (String)


803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 803

class GetMicrovmResponse < Struct.new(
  :microvm_id,
  :state,
  :endpoint,
  :image_arn,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :maximum_duration_in_seconds,
  :started_at,
  :terminated_at,
  :state_reason,
  :ingress_network_connectors,
  :egress_network_connectors)
  SENSITIVE = []
  include Aws::Structure
end

#idle_policyTypes::IdlePolicy

The idle policy configuration of the MicroVM, controlling auto-suspend and auto-resume behavior.

Returns:



803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 803

class GetMicrovmResponse < Struct.new(
  :microvm_id,
  :state,
  :endpoint,
  :image_arn,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :maximum_duration_in_seconds,
  :started_at,
  :terminated_at,
  :state_reason,
  :ingress_network_connectors,
  :egress_network_connectors)
  SENSITIVE = []
  include Aws::Structure
end

#image_arnString

The ARN of the MicroVM image used to run this MicroVM.

Returns:

  • (String)


803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 803

class GetMicrovmResponse < Struct.new(
  :microvm_id,
  :state,
  :endpoint,
  :image_arn,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :maximum_duration_in_seconds,
  :started_at,
  :terminated_at,
  :state_reason,
  :ingress_network_connectors,
  :egress_network_connectors)
  SENSITIVE = []
  include Aws::Structure
end

#image_versionString

The version of the MicroVM image used to run this MicroVM.

Returns:

  • (String)


803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 803

class GetMicrovmResponse < Struct.new(
  :microvm_id,
  :state,
  :endpoint,
  :image_arn,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :maximum_duration_in_seconds,
  :started_at,
  :terminated_at,
  :state_reason,
  :ingress_network_connectors,
  :egress_network_connectors)
  SENSITIVE = []
  include Aws::Structure
end

#ingress_network_connectorsArray<String>

The list of ingress network connectors configured for the MicroVM.

Returns:

  • (Array<String>)


803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 803

class GetMicrovmResponse < Struct.new(
  :microvm_id,
  :state,
  :endpoint,
  :image_arn,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :maximum_duration_in_seconds,
  :started_at,
  :terminated_at,
  :state_reason,
  :ingress_network_connectors,
  :egress_network_connectors)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_duration_in_secondsInteger

The maximum duration in seconds that the MicroVM can exist before being terminated by the platform.

Returns:

  • (Integer)


803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 803

class GetMicrovmResponse < Struct.new(
  :microvm_id,
  :state,
  :endpoint,
  :image_arn,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :maximum_duration_in_seconds,
  :started_at,
  :terminated_at,
  :state_reason,
  :ingress_network_connectors,
  :egress_network_connectors)
  SENSITIVE = []
  include Aws::Structure
end

#microvm_idString

The unique identifier of the MicroVM.

Returns:

  • (String)


803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 803

class GetMicrovmResponse < Struct.new(
  :microvm_id,
  :state,
  :endpoint,
  :image_arn,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :maximum_duration_in_seconds,
  :started_at,
  :terminated_at,
  :state_reason,
  :ingress_network_connectors,
  :egress_network_connectors)
  SENSITIVE = []
  include Aws::Structure
end

#started_atTime

The timestamp when the MicroVM first started.

Returns:

  • (Time)


803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 803

class GetMicrovmResponse < Struct.new(
  :microvm_id,
  :state,
  :endpoint,
  :image_arn,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :maximum_duration_in_seconds,
  :started_at,
  :terminated_at,
  :state_reason,
  :ingress_network_connectors,
  :egress_network_connectors)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The current lifecycle state of the MicroVM.

Returns:

  • (String)


803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 803

class GetMicrovmResponse < Struct.new(
  :microvm_id,
  :state,
  :endpoint,
  :image_arn,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :maximum_duration_in_seconds,
  :started_at,
  :terminated_at,
  :state_reason,
  :ingress_network_connectors,
  :egress_network_connectors)
  SENSITIVE = []
  include Aws::Structure
end

#state_reasonString

The reason for why the MicroVM is in the current state.

Returns:

  • (String)


803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 803

class GetMicrovmResponse < Struct.new(
  :microvm_id,
  :state,
  :endpoint,
  :image_arn,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :maximum_duration_in_seconds,
  :started_at,
  :terminated_at,
  :state_reason,
  :ingress_network_connectors,
  :egress_network_connectors)
  SENSITIVE = []
  include Aws::Structure
end

#terminated_atTime

The timestamp when the MicroVM terminated.

Returns:

  • (Time)


803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 803

class GetMicrovmResponse < Struct.new(
  :microvm_id,
  :state,
  :endpoint,
  :image_arn,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :maximum_duration_in_seconds,
  :started_at,
  :terminated_at,
  :state_reason,
  :ingress_network_connectors,
  :egress_network_connectors)
  SENSITIVE = []
  include Aws::Structure
end