Class: Aws::LambdaMicrovms::Types::IdlePolicy

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambdamicrovms/types.rb

Overview

Configuration that controls MicroVM auto-suspend and auto-resume behavior. Idle time is measured by inbound traffic through the MicroVM proxy endpoint — if no requests arrive within the configured duration, the MicroVM is suspended.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_resume_enabledBoolean

Indicates whether the MicroVM automatically resumes when it receives a request while suspended.

Returns:

  • (Boolean)


867
868
869
870
871
872
873
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 867

class IdlePolicy < Struct.new(
  :max_idle_duration_seconds,
  :suspended_duration_seconds,
  :auto_resume_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#max_idle_duration_secondsInteger

The maximum time in seconds that a MicroVM can remain idle before it is automatically suspended.

Returns:

  • (Integer)


867
868
869
870
871
872
873
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 867

class IdlePolicy < Struct.new(
  :max_idle_duration_seconds,
  :suspended_duration_seconds,
  :auto_resume_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#suspended_duration_secondsInteger

The maximum time in seconds that a MicroVM can remain suspended before it is automatically terminated.

Returns:

  • (Integer)


867
868
869
870
871
872
873
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 867

class IdlePolicy < Struct.new(
  :max_idle_duration_seconds,
  :suspended_duration_seconds,
  :auto_resume_enabled)
  SENSITIVE = []
  include Aws::Structure
end