Class: Aws::LambdaMicrovms::Types::InternalServerException
- Inherits:
-
Struct
- Object
- Struct
- Aws::LambdaMicrovms::Types::InternalServerException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambdamicrovms/types.rb
Overview
An internal server error occurred. Retry the request later.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #message ⇒ String
-
#retry_after_seconds ⇒ Integer
The number of seconds to wait before retrying the request.
Instance Attribute Details
#message ⇒ String
886 887 888 889 890 891 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 886 class InternalServerException < Struct.new( :message, :retry_after_seconds) SENSITIVE = [] include Aws::Structure end |
#retry_after_seconds ⇒ Integer
The number of seconds to wait before retrying the request.
886 887 888 889 890 891 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 886 class InternalServerException < Struct.new( :message, :retry_after_seconds) SENSITIVE = [] include Aws::Structure end |