Class: Aws::LambdaMicrovms::Types::Logging

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-lambdamicrovms/types.rb

Overview

Note:

Logging is a union - when making an API calls you must set exactly one of the members.

Note:

Logging is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of Logging corresponding to the set member.

Configuration for MicroVM logging output. Specify exactly one: cloudWatch to enable CloudWatch logging, or disabled to turn off logging.

Direct Known Subclasses

CloudWatch, Disabled, Unknown

Defined Under Namespace

Classes: CloudWatch, Disabled, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_watchTypes::CloudWatchLogging

Configuration for sending logs to Amazon CloudWatch Logs.



1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1228

class Logging < Struct.new(
  :disabled,
  :cloud_watch,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Disabled < Logging; end
  class CloudWatch < Logging; end
  class Unknown < Logging; end
end

#disabledTypes::LoggingDisabled

Specifies that logging is disabled.



1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1228

class Logging < Struct.new(
  :disabled,
  :cloud_watch,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Disabled < Logging; end
  class CloudWatch < Logging; end
  class Unknown < Logging; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



1228
1229
1230
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1228

def unknown
  @unknown
end