Class: Aws::LambdaMicrovms::Types::MicrovmImageHooks
- Inherits:
-
Struct
- Object
- Struct
- Aws::LambdaMicrovms::Types::MicrovmImageHooks
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambdamicrovms/types.rb
Overview
Configuration for hooks invoked during MicroVM image build events such as ready and validate.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ready ⇒ String
The path of the hook invoked when the MicroVM image build is ready.
-
#ready_timeout_in_seconds ⇒ Integer
The maximum time in seconds for the ready hook to complete.
-
#validate ⇒ String
The path of the hook invoked to validate the MicroVM image build.
-
#validate_timeout_in_seconds ⇒ Integer
The maximum time in seconds for the validate hook to complete.
Instance Attribute Details
#ready ⇒ String
The path of the hook invoked when the MicroVM image build is ready.
1428 1429 1430 1431 1432 1433 1434 1435 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1428 class MicrovmImageHooks < Struct.new( :ready, :ready_timeout_in_seconds, :validate, :validate_timeout_in_seconds) SENSITIVE = [] include Aws::Structure end |
#ready_timeout_in_seconds ⇒ Integer
The maximum time in seconds for the ready hook to complete.
1428 1429 1430 1431 1432 1433 1434 1435 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1428 class MicrovmImageHooks < Struct.new( :ready, :ready_timeout_in_seconds, :validate, :validate_timeout_in_seconds) SENSITIVE = [] include Aws::Structure end |
#validate ⇒ String
The path of the hook invoked to validate the MicroVM image build.
1428 1429 1430 1431 1432 1433 1434 1435 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1428 class MicrovmImageHooks < Struct.new( :ready, :ready_timeout_in_seconds, :validate, :validate_timeout_in_seconds) SENSITIVE = [] include Aws::Structure end |
#validate_timeout_in_seconds ⇒ Integer
The maximum time in seconds for the validate hook to complete.
1428 1429 1430 1431 1432 1433 1434 1435 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1428 class MicrovmImageHooks < Struct.new( :ready, :ready_timeout_in_seconds, :validate, :validate_timeout_in_seconds) SENSITIVE = [] include Aws::Structure end |