Class: Aws::LambdaMicrovms::Types::MicrovmImageVersionSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::LambdaMicrovms::Types::MicrovmImageVersionSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambdamicrovms/types.rb
Overview
Contains summary information about a version of a MicroVM image.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_os_capabilities ⇒ Array<String>
Additional OS capabilities granted to the MicroVM runtime environment.
-
#base_image_arn ⇒ String
The ARN of the base MicroVM image used.
-
#base_image_version ⇒ String
The specific version of the base MicroVM image.
-
#build_role_arn ⇒ String
The ARN of the IAM build role.
-
#code_artifact ⇒ Types::CodeArtifact
The code artifact for this version.
-
#cpu_configurations ⇒ Array<Types::CpuConfiguration>
The list of supported CPU configurations for the MicroVM.
-
#created_at ⇒ Time
The timestamp when the version was created.
-
#description ⇒ String
The description of the version.
-
#egress_network_connectors ⇒ Array<String>
The list of egress network connectors available to the MicroVM at runtime.
-
#environment_variables ⇒ Hash<String,String>
Environment variables set in the MicroVM runtime environment.
-
#hooks ⇒ Types::Hooks
Lifecycle hook configuration for MicroVMs and MicroVM images.
-
#image_arn ⇒ String
The ARN of the MicroVM image.
-
#image_version ⇒ String
The version of the MicroVM image.
-
#logging ⇒ Types::Logging
The logging configuration for this version.
-
#resources ⇒ Array<Types::Resources>
The resource requirements for the MicroVM.
-
#state ⇒ String
The current state of the version.
-
#state_reason ⇒ String
The reason for the current state.
-
#status ⇒ String
The availability status of the version: ACTIVE (can be used by RunMicrovm) or INACTIVE (blocked from launching new MicroVMs).
-
#tags ⇒ Hash<String,String>
Key-value pairs associated with the version.
-
#updated_at ⇒ Time
The timestamp when the version was last updated.
Instance Attribute Details
#additional_os_capabilities ⇒ Array<String>
Additional OS capabilities granted to the MicroVM runtime environment.
1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1564 class MicrovmImageVersionSummary < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#base_image_arn ⇒ String
The ARN of the base MicroVM image used.
1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1564 class MicrovmImageVersionSummary < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#base_image_version ⇒ String
The specific version of the base MicroVM image.
1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1564 class MicrovmImageVersionSummary < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#build_role_arn ⇒ String
The ARN of the IAM build role.
1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1564 class MicrovmImageVersionSummary < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#code_artifact ⇒ Types::CodeArtifact
The code artifact for this version.
1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1564 class MicrovmImageVersionSummary < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#cpu_configurations ⇒ Array<Types::CpuConfiguration>
The list of supported CPU configurations for the MicroVM.
1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1564 class MicrovmImageVersionSummary < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when the version was created.
1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1564 class MicrovmImageVersionSummary < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the version.
1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1564 class MicrovmImageVersionSummary < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#egress_network_connectors ⇒ Array<String>
The list of egress network connectors available to the MicroVM at runtime.
1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1564 class MicrovmImageVersionSummary < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#environment_variables ⇒ Hash<String,String>
Environment variables set in the MicroVM runtime environment.
1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1564 class MicrovmImageVersionSummary < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#hooks ⇒ Types::Hooks
Lifecycle hook configuration for MicroVMs and MicroVM images.
1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1564 class MicrovmImageVersionSummary < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#image_arn ⇒ String
The ARN of the MicroVM image.
1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1564 class MicrovmImageVersionSummary < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#image_version ⇒ String
The version of the MicroVM image.
1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1564 class MicrovmImageVersionSummary < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#logging ⇒ Types::Logging
The logging configuration for this version.
1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1564 class MicrovmImageVersionSummary < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#resources ⇒ Array<Types::Resources>
The resource requirements for the MicroVM.
1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1564 class MicrovmImageVersionSummary < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the version.
1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1564 class MicrovmImageVersionSummary < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#state_reason ⇒ String
The reason for the current state. For example, one or more builds failed.
1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1564 class MicrovmImageVersionSummary < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The availability status of the version: ACTIVE (can be used by RunMicrovm) or INACTIVE (blocked from launching new MicroVMs).
1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1564 class MicrovmImageVersionSummary < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Key-value pairs associated with the version.
1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1564 class MicrovmImageVersionSummary < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp when the version was last updated.
1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1564 class MicrovmImageVersionSummary < Struct.new( :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :image_arn, :image_version, :state, :status, :created_at, :updated_at, :state_reason, :tags) SENSITIVE = [] include Aws::Structure end |