Class: Aws::LambdaMicrovms::Types::PortSpecification

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-lambdamicrovms/types.rb

Overview

Note:

PortSpecification is a union - when making an API calls you must set exactly one of the members.

Specifies which ports are accessible on a MicroVM. Only one of the port specification options can be set.

Direct Known Subclasses

AllPorts, Port, Range, Unknown

Defined Under Namespace

Classes: AllPorts, Port, Range, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#all_portsTypes::Unit

Indicates that all ports are accessible.

Returns:



1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1661

class PortSpecification < Struct.new(
  :port,
  :range,
  :all_ports,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Port < PortSpecification; end
  class Range < PortSpecification; end
  class AllPorts < PortSpecification; end
  class Unknown < PortSpecification; end
end

#portInteger

A single port number.

Returns:

  • (Integer)


1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1661

class PortSpecification < Struct.new(
  :port,
  :range,
  :all_ports,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Port < PortSpecification; end
  class Range < PortSpecification; end
  class AllPorts < PortSpecification; end
  class Unknown < PortSpecification; end
end

#rangeTypes::PortRange

A range of ports.

Returns:



1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1661

class PortSpecification < Struct.new(
  :port,
  :range,
  :all_ports,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Port < PortSpecification; end
  class Range < PortSpecification; end
  class AllPorts < PortSpecification; end
  class Unknown < PortSpecification; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



1661
1662
1663
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1661

def unknown
  @unknown
end