Class: Aws::LambdaMicrovms::Types::ResourceNotFoundException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambdamicrovms/types.rb

Overview

The specified resource does not exist.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


1729
1730
1731
1732
1733
1734
1735
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1729

class ResourceNotFoundException < Struct.new(
  :message,
  :resource_type,
  :resource_id)
  SENSITIVE = []
  include Aws::Structure
end

#resource_idString

The identifier of the resource that was not found.

Returns:

  • (String)


1729
1730
1731
1732
1733
1734
1735
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1729

class ResourceNotFoundException < Struct.new(
  :message,
  :resource_type,
  :resource_id)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The type of the resource that was not found.

Returns:

  • (String)


1729
1730
1731
1732
1733
1734
1735
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1729

class ResourceNotFoundException < Struct.new(
  :message,
  :resource_type,
  :resource_id)
  SENSITIVE = []
  include Aws::Structure
end