Class: Aws::LambdaMicrovms::Types::RunMicrovmRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambdamicrovms/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:run_hook_payload]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier you provide to ensure the idempotency of the request.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1820

class RunMicrovmRequest < Struct.new(
  :ingress_network_connectors,
  :egress_network_connectors,
  :image_identifier,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :logging,
  :run_hook_payload,
  :maximum_duration_in_seconds,
  :client_token)
  SENSITIVE = [:run_hook_payload]
  include Aws::Structure
end

#egress_network_connectorsArray<String>

The list of egress network connectors to configure for the MicroVM.

Returns:

  • (Array<String>)


1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1820

class RunMicrovmRequest < Struct.new(
  :ingress_network_connectors,
  :egress_network_connectors,
  :image_identifier,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :logging,
  :run_hook_payload,
  :maximum_duration_in_seconds,
  :client_token)
  SENSITIVE = [:run_hook_payload]
  include Aws::Structure
end

#execution_role_arnString

The ARN of the IAM role to be assumed by the MicroVM during execution.

Returns:

  • (String)


1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1820

class RunMicrovmRequest < Struct.new(
  :ingress_network_connectors,
  :egress_network_connectors,
  :image_identifier,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :logging,
  :run_hook_payload,
  :maximum_duration_in_seconds,
  :client_token)
  SENSITIVE = [:run_hook_payload]
  include Aws::Structure
end

#idle_policyTypes::IdlePolicy

Configuration to control auto-suspend and auto-resume behavior.

Returns:



1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1820

class RunMicrovmRequest < Struct.new(
  :ingress_network_connectors,
  :egress_network_connectors,
  :image_identifier,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :logging,
  :run_hook_payload,
  :maximum_duration_in_seconds,
  :client_token)
  SENSITIVE = [:run_hook_payload]
  include Aws::Structure
end

#image_identifierString

The identifier (ARN or ID) of the MicroVM image to run.

Returns:

  • (String)


1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1820

class RunMicrovmRequest < Struct.new(
  :ingress_network_connectors,
  :egress_network_connectors,
  :image_identifier,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :logging,
  :run_hook_payload,
  :maximum_duration_in_seconds,
  :client_token)
  SENSITIVE = [:run_hook_payload]
  include Aws::Structure
end

#image_versionString

The version of the MicroVM image to run.

Returns:

  • (String)


1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1820

class RunMicrovmRequest < Struct.new(
  :ingress_network_connectors,
  :egress_network_connectors,
  :image_identifier,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :logging,
  :run_hook_payload,
  :maximum_duration_in_seconds,
  :client_token)
  SENSITIVE = [:run_hook_payload]
  include Aws::Structure
end

#ingress_network_connectorsArray<String>

The list of ingress network connectors to configure for the MicroVM.

Returns:

  • (Array<String>)


1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1820

class RunMicrovmRequest < Struct.new(
  :ingress_network_connectors,
  :egress_network_connectors,
  :image_identifier,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :logging,
  :run_hook_payload,
  :maximum_duration_in_seconds,
  :client_token)
  SENSITIVE = [:run_hook_payload]
  include Aws::Structure
end

#loggingTypes::Logging

The logging configuration for this MicroVM instance. Specify {"logGroup": "..."} to stream application logs to a custom CloudWatch log group, or {} to turn off logging.

Returns:



1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1820

class RunMicrovmRequest < Struct.new(
  :ingress_network_connectors,
  :egress_network_connectors,
  :image_identifier,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :logging,
  :run_hook_payload,
  :maximum_duration_in_seconds,
  :client_token)
  SENSITIVE = [:run_hook_payload]
  include Aws::Structure
end

#maximum_duration_in_secondsInteger

The maximum duration in seconds that the MicroVM can exist before being terminated by the platform. Valid range: 1–28,800 (8 hours).

Returns:

  • (Integer)


1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1820

class RunMicrovmRequest < Struct.new(
  :ingress_network_connectors,
  :egress_network_connectors,
  :image_identifier,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :logging,
  :run_hook_payload,
  :maximum_duration_in_seconds,
  :client_token)
  SENSITIVE = [:run_hook_payload]
  include Aws::Structure
end

#run_hook_payloadString

Per-MicroVM initialization data delivered as the request body of the /run lifecycle hook. Use to pass tenant-specific configuration such as session IDs or secret references. Maximum: 16,384 bytes.

Returns:

  • (String)


1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1820

class RunMicrovmRequest < Struct.new(
  :ingress_network_connectors,
  :egress_network_connectors,
  :image_identifier,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :logging,
  :run_hook_payload,
  :maximum_duration_in_seconds,
  :client_token)
  SENSITIVE = [:run_hook_payload]
  include Aws::Structure
end