Class: Aws::LambdaMicrovms::Types::ServiceQuotaExceededException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambdamicrovms/types.rb

Overview

You have exceeded a service quota for Lambda MicroVMs.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


1930
1931
1932
1933
1934
1935
1936
1937
1938
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1930

class ServiceQuotaExceededException < Struct.new(
  :message,
  :resource_id,
  :resource_type,
  :service_code,
  :quota_code)
  SENSITIVE = []
  include Aws::Structure
end

#quota_codeString

The quota code of the exceeded service quota.

Returns:

  • (String)


1930
1931
1932
1933
1934
1935
1936
1937
1938
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1930

class ServiceQuotaExceededException < Struct.new(
  :message,
  :resource_id,
  :resource_type,
  :service_code,
  :quota_code)
  SENSITIVE = []
  include Aws::Structure
end

#resource_idString

The identifier of the resource that exceeded the quota.

Returns:

  • (String)


1930
1931
1932
1933
1934
1935
1936
1937
1938
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1930

class ServiceQuotaExceededException < Struct.new(
  :message,
  :resource_id,
  :resource_type,
  :service_code,
  :quota_code)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The type of the resource that exceeded the quota.

Returns:

  • (String)


1930
1931
1932
1933
1934
1935
1936
1937
1938
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1930

class ServiceQuotaExceededException < Struct.new(
  :message,
  :resource_id,
  :resource_type,
  :service_code,
  :quota_code)
  SENSITIVE = []
  include Aws::Structure
end

#service_codeString

The service code of the exceeded service quota.

Returns:

  • (String)


1930
1931
1932
1933
1934
1935
1936
1937
1938
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1930

class ServiceQuotaExceededException < Struct.new(
  :message,
  :resource_id,
  :resource_type,
  :service_code,
  :quota_code)
  SENSITIVE = []
  include Aws::Structure
end