Class: Aws::LambdaMicrovms::Types::ThrottlingException
- Inherits:
-
Struct
- Object
- Struct
- Aws::LambdaMicrovms::Types::ThrottlingException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambdamicrovms/types.rb
Overview
The request was denied due to request throttling. Retry the request later.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #message ⇒ String
-
#quota_code ⇒ String
The quota code of the throttled service quota.
-
#retry_after_seconds ⇒ Integer
The number of seconds to wait before retrying the request.
-
#service_code ⇒ String
The service code of the throttled service quota.
Instance Attribute Details
#message ⇒ String
2053 2054 2055 2056 2057 2058 2059 2060 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 2053 class ThrottlingException < Struct.new( :message, :service_code, :quota_code, :retry_after_seconds) SENSITIVE = [] include Aws::Structure end |
#quota_code ⇒ String
The quota code of the throttled service quota.
2053 2054 2055 2056 2057 2058 2059 2060 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 2053 class ThrottlingException < Struct.new( :message, :service_code, :quota_code, :retry_after_seconds) SENSITIVE = [] include Aws::Structure end |
#retry_after_seconds ⇒ Integer
The number of seconds to wait before retrying the request.
2053 2054 2055 2056 2057 2058 2059 2060 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 2053 class ThrottlingException < Struct.new( :message, :service_code, :quota_code, :retry_after_seconds) SENSITIVE = [] include Aws::Structure end |
#service_code ⇒ String
The service code of the throttled service quota.
2053 2054 2055 2056 2057 2058 2059 2060 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 2053 class ThrottlingException < Struct.new( :message, :service_code, :quota_code, :retry_after_seconds) SENSITIVE = [] include Aws::Structure end |