Class: Aws::LambdaMicrovms::Types::UpdateMicrovmImageResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LambdaMicrovms::Types::UpdateMicrovmImageResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambdamicrovms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:environment_variables]
Instance Attribute Summary collapse
-
#additional_os_capabilities ⇒ Array<String>
Additional OS capabilities granted to the MicroVM runtime environment.
-
#base_image_arn ⇒ String
The ARN of the base MicroVM image.
-
#base_image_version ⇒ String
The specific version of the base MicroVM image.
-
#build_role_arn ⇒ String
The ARN of the IAM build role.
-
#code_artifact ⇒ Types::CodeArtifact
The code artifact containing the application code and metadata for the MicroVM image.
-
#cpu_configurations ⇒ Array<Types::CpuConfiguration>
The list of supported CPU configurations for the MicroVM.
-
#created_at ⇒ Time
The timestamp when the MicroVM image was created.
-
#description ⇒ String
The description of the MicroVM image.
-
#egress_network_connectors ⇒ Array<String>
The list of egress network connectors available to the MicroVM at runtime.
-
#environment_variables ⇒ Hash<String,String>
Environment variables set in the MicroVM runtime environment.
-
#hooks ⇒ Types::Hooks
Lifecycle hook configuration for MicroVMs and MicroVM images.
-
#image_arn ⇒ String
The ARN of the MicroVM image.
-
#image_version ⇒ String
The version of the MicroVM image.
-
#latest_active_image_version ⇒ String
The latest active version of the MicroVM image.
-
#latest_failed_image_version ⇒ String
The latest failed version of the MicroVM image, if any.
-
#logging ⇒ Types::Logging
The logging configuration for build-time and runtime logs.
-
#name ⇒ String
The name of the MicroVM image.
-
#resources ⇒ Array<Types::Resources>
The resource requirements for the MicroVM.
-
#state ⇒ String
The current state of the MicroVM image.
-
#updated_at ⇒ Time
The timestamp when the MicroVM image was last updated.
Instance Attribute Details
#additional_os_capabilities ⇒ Array<String>
Additional OS capabilities granted to the MicroVM runtime environment.
2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 2278 class UpdateMicrovmImageResponse < Struct.new( :image_arn, :name, :state, :latest_active_image_version, :latest_failed_image_version, :created_at, :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :updated_at, :image_version) SENSITIVE = [:environment_variables] include Aws::Structure end |
#base_image_arn ⇒ String
The ARN of the base MicroVM image.
2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 2278 class UpdateMicrovmImageResponse < Struct.new( :image_arn, :name, :state, :latest_active_image_version, :latest_failed_image_version, :created_at, :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :updated_at, :image_version) SENSITIVE = [:environment_variables] include Aws::Structure end |
#base_image_version ⇒ String
The specific version of the base MicroVM image.
2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 2278 class UpdateMicrovmImageResponse < Struct.new( :image_arn, :name, :state, :latest_active_image_version, :latest_failed_image_version, :created_at, :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :updated_at, :image_version) SENSITIVE = [:environment_variables] include Aws::Structure end |
#build_role_arn ⇒ String
The ARN of the IAM build role.
2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 2278 class UpdateMicrovmImageResponse < Struct.new( :image_arn, :name, :state, :latest_active_image_version, :latest_failed_image_version, :created_at, :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :updated_at, :image_version) SENSITIVE = [:environment_variables] include Aws::Structure end |
#code_artifact ⇒ Types::CodeArtifact
The code artifact containing the application code and metadata for the MicroVM image.
2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 2278 class UpdateMicrovmImageResponse < Struct.new( :image_arn, :name, :state, :latest_active_image_version, :latest_failed_image_version, :created_at, :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :updated_at, :image_version) SENSITIVE = [:environment_variables] include Aws::Structure end |
#cpu_configurations ⇒ Array<Types::CpuConfiguration>
The list of supported CPU configurations for the MicroVM.
2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 2278 class UpdateMicrovmImageResponse < Struct.new( :image_arn, :name, :state, :latest_active_image_version, :latest_failed_image_version, :created_at, :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :updated_at, :image_version) SENSITIVE = [:environment_variables] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when the MicroVM image was created.
2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 2278 class UpdateMicrovmImageResponse < Struct.new( :image_arn, :name, :state, :latest_active_image_version, :latest_failed_image_version, :created_at, :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :updated_at, :image_version) SENSITIVE = [:environment_variables] include Aws::Structure end |
#description ⇒ String
The description of the MicroVM image.
2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 2278 class UpdateMicrovmImageResponse < Struct.new( :image_arn, :name, :state, :latest_active_image_version, :latest_failed_image_version, :created_at, :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :updated_at, :image_version) SENSITIVE = [:environment_variables] include Aws::Structure end |
#egress_network_connectors ⇒ Array<String>
The list of egress network connectors available to the MicroVM at runtime.
2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 2278 class UpdateMicrovmImageResponse < Struct.new( :image_arn, :name, :state, :latest_active_image_version, :latest_failed_image_version, :created_at, :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :updated_at, :image_version) SENSITIVE = [:environment_variables] include Aws::Structure end |
#environment_variables ⇒ Hash<String,String>
Environment variables set in the MicroVM runtime environment.
2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 2278 class UpdateMicrovmImageResponse < Struct.new( :image_arn, :name, :state, :latest_active_image_version, :latest_failed_image_version, :created_at, :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :updated_at, :image_version) SENSITIVE = [:environment_variables] include Aws::Structure end |
#hooks ⇒ Types::Hooks
Lifecycle hook configuration for MicroVMs and MicroVM images.
2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 2278 class UpdateMicrovmImageResponse < Struct.new( :image_arn, :name, :state, :latest_active_image_version, :latest_failed_image_version, :created_at, :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :updated_at, :image_version) SENSITIVE = [:environment_variables] include Aws::Structure end |
#image_arn ⇒ String
The ARN of the MicroVM image.
2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 2278 class UpdateMicrovmImageResponse < Struct.new( :image_arn, :name, :state, :latest_active_image_version, :latest_failed_image_version, :created_at, :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :updated_at, :image_version) SENSITIVE = [:environment_variables] include Aws::Structure end |
#image_version ⇒ String
The version of the MicroVM image.
2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 2278 class UpdateMicrovmImageResponse < Struct.new( :image_arn, :name, :state, :latest_active_image_version, :latest_failed_image_version, :created_at, :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :updated_at, :image_version) SENSITIVE = [:environment_variables] include Aws::Structure end |
#latest_active_image_version ⇒ String
The latest active version of the MicroVM image.
2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 2278 class UpdateMicrovmImageResponse < Struct.new( :image_arn, :name, :state, :latest_active_image_version, :latest_failed_image_version, :created_at, :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :updated_at, :image_version) SENSITIVE = [:environment_variables] include Aws::Structure end |
#latest_failed_image_version ⇒ String
The latest failed version of the MicroVM image, if any.
2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 2278 class UpdateMicrovmImageResponse < Struct.new( :image_arn, :name, :state, :latest_active_image_version, :latest_failed_image_version, :created_at, :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :updated_at, :image_version) SENSITIVE = [:environment_variables] include Aws::Structure end |
#logging ⇒ Types::Logging
The logging configuration for build-time and runtime logs. Specify {"logGroup": "..."} to stream logs to a custom CloudWatch log group, or {} to turn off logging.
2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 2278 class UpdateMicrovmImageResponse < Struct.new( :image_arn, :name, :state, :latest_active_image_version, :latest_failed_image_version, :created_at, :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :updated_at, :image_version) SENSITIVE = [:environment_variables] include Aws::Structure end |
#name ⇒ String
The name of the MicroVM image.
2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 2278 class UpdateMicrovmImageResponse < Struct.new( :image_arn, :name, :state, :latest_active_image_version, :latest_failed_image_version, :created_at, :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :updated_at, :image_version) SENSITIVE = [:environment_variables] include Aws::Structure end |
#resources ⇒ Array<Types::Resources>
The resource requirements for the MicroVM.
2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 2278 class UpdateMicrovmImageResponse < Struct.new( :image_arn, :name, :state, :latest_active_image_version, :latest_failed_image_version, :created_at, :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :updated_at, :image_version) SENSITIVE = [:environment_variables] include Aws::Structure end |
#state ⇒ String
The current state of the MicroVM image.
2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 2278 class UpdateMicrovmImageResponse < Struct.new( :image_arn, :name, :state, :latest_active_image_version, :latest_failed_image_version, :created_at, :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :updated_at, :image_version) SENSITIVE = [:environment_variables] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp when the MicroVM image was last updated.
2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 2278 class UpdateMicrovmImageResponse < Struct.new( :image_arn, :name, :state, :latest_active_image_version, :latest_failed_image_version, :created_at, :base_image_arn, :base_image_version, :build_role_arn, :description, :code_artifact, :logging, :egress_network_connectors, :cpu_configurations, :resources, :additional_os_capabilities, :hooks, :environment_variables, :updated_at, :image_version) SENSITIVE = [:environment_variables] include Aws::Structure end |