Class: Aws::LambdaMicrovms::Types::CodeArtifact
- Inherits:
-
Struct
- Object
- Struct
- Aws::LambdaMicrovms::Types::CodeArtifact
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-lambdamicrovms/types.rb
Overview
Note:
CodeArtifact is a union - when making an API calls you must set exactly one of the members.
Note:
CodeArtifact is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of CodeArtifact corresponding to the set member.
Contains the location of the code artifact for a MicroVM image.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#unknown ⇒ Object
Returns the value of attribute unknown.
-
#uri ⇒ String
The URI of the code artifact, such as an Amazon S3 path or Amazon ECR image URI.
Instance Attribute Details
#unknown ⇒ Object
Returns the value of attribute unknown
58 59 60 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 58 def unknown @unknown end |
#uri ⇒ String
The URI of the code artifact, such as an Amazon S3 path or Amazon ECR image URI.
58 59 60 61 62 63 64 65 66 67 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 58 class CodeArtifact < Struct.new( :uri, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Uri < CodeArtifact; end class Unknown < CodeArtifact; end end |