Class: Aws::LambdaMicrovms::Types::CreateMicrovmAuthTokenRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LambdaMicrovms::Types::CreateMicrovmAuthTokenRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambdamicrovms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed_ports ⇒ Array<Types::PortSpecification>
The list of port specifications that the authentication token grants access to on the MicroVM.
-
#expiration_in_minutes ⇒ Integer
The duration in minutes before the authentication token expires.
-
#microvm_identifier ⇒ String
The ID of the MicroVM to create an authentication token for.
Instance Attribute Details
#allowed_ports ⇒ Array<Types::PortSpecification>
The list of port specifications that the authentication token grants access to on the MicroVM.
123 124 125 126 127 128 129 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 123 class CreateMicrovmAuthTokenRequest < Struct.new( :microvm_identifier, :expiration_in_minutes, :allowed_ports) SENSITIVE = [] include Aws::Structure end |
#expiration_in_minutes ⇒ Integer
The duration in minutes before the authentication token expires. Maximum: 60 minutes.
123 124 125 126 127 128 129 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 123 class CreateMicrovmAuthTokenRequest < Struct.new( :microvm_identifier, :expiration_in_minutes, :allowed_ports) SENSITIVE = [] include Aws::Structure end |
#microvm_identifier ⇒ String
The ID of the MicroVM to create an authentication token for.
123 124 125 126 127 128 129 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 123 class CreateMicrovmAuthTokenRequest < Struct.new( :microvm_identifier, :expiration_in_minutes, :allowed_ports) SENSITIVE = [] include Aws::Structure end |