Class: Aws::LambdaMicrovms::Types::GetMicrovmImageOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::LambdaMicrovms::Types::GetMicrovmImageOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambdamicrovms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp when the MicroVM image was created.
-
#image_arn ⇒ String
The ARN of the MicroVM image.
-
#latest_active_image_version ⇒ String
The latest active version of the MicroVM image.
-
#latest_failed_image_version ⇒ String
The latest failed version of the MicroVM image, if any.
-
#name ⇒ String
The name of the MicroVM image.
-
#state ⇒ String
The current state of the MicroVM image.
-
#tags ⇒ Hash<String,String>
A set of key-value pairs that you can attach to the resource.
-
#updated_at ⇒ Time
The timestamp when the MicroVM image was last updated.
Instance Attribute Details
#created_at ⇒ Time
The timestamp when the MicroVM image was created.
592 593 594 595 596 597 598 599 600 601 602 603 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 592 class GetMicrovmImageOutput < Struct.new( :image_arn, :name, :state, :latest_active_image_version, :latest_failed_image_version, :created_at, :tags, :updated_at) SENSITIVE = [] include Aws::Structure end |
#image_arn ⇒ String
The ARN of the MicroVM image.
592 593 594 595 596 597 598 599 600 601 602 603 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 592 class GetMicrovmImageOutput < Struct.new( :image_arn, :name, :state, :latest_active_image_version, :latest_failed_image_version, :created_at, :tags, :updated_at) SENSITIVE = [] include Aws::Structure end |
#latest_active_image_version ⇒ String
The latest active version of the MicroVM image.
592 593 594 595 596 597 598 599 600 601 602 603 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 592 class GetMicrovmImageOutput < Struct.new( :image_arn, :name, :state, :latest_active_image_version, :latest_failed_image_version, :created_at, :tags, :updated_at) SENSITIVE = [] include Aws::Structure end |
#latest_failed_image_version ⇒ String
The latest failed version of the MicroVM image, if any.
592 593 594 595 596 597 598 599 600 601 602 603 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 592 class GetMicrovmImageOutput < Struct.new( :image_arn, :name, :state, :latest_active_image_version, :latest_failed_image_version, :created_at, :tags, :updated_at) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the MicroVM image.
592 593 594 595 596 597 598 599 600 601 602 603 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 592 class GetMicrovmImageOutput < Struct.new( :image_arn, :name, :state, :latest_active_image_version, :latest_failed_image_version, :created_at, :tags, :updated_at) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the MicroVM image.
592 593 594 595 596 597 598 599 600 601 602 603 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 592 class GetMicrovmImageOutput < Struct.new( :image_arn, :name, :state, :latest_active_image_version, :latest_failed_image_version, :created_at, :tags, :updated_at) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A set of key-value pairs that you can attach to the resource. Use tags to categorize resources for cost allocation, access control (ABAC), and organization.
592 593 594 595 596 597 598 599 600 601 602 603 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 592 class GetMicrovmImageOutput < Struct.new( :image_arn, :name, :state, :latest_active_image_version, :latest_failed_image_version, :created_at, :tags, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp when the MicroVM image was last updated.
592 593 594 595 596 597 598 599 600 601 602 603 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 592 class GetMicrovmImageOutput < Struct.new( :image_arn, :name, :state, :latest_active_image_version, :latest_failed_image_version, :created_at, :tags, :updated_at) SENSITIVE = [] include Aws::Structure end |