Class: Aws::LambdaMicrovms::Types::GetMicrovmResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LambdaMicrovms::Types::GetMicrovmResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambdamicrovms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#egress_network_connectors ⇒ Array<String>
The list of egress network connectors configured for the MicroVM.
-
#endpoint ⇒ String
The HTTPS endpoint URL for communicating with the MicroVM.
-
#execution_role_arn ⇒ String
The ARN of the IAM execution role assumed by the MicroVM.
-
#idle_policy ⇒ Types::IdlePolicy
The idle policy configuration of the MicroVM, controlling auto-suspend and auto-resume behavior.
-
#image_arn ⇒ String
The ARN of the MicroVM image used to run this MicroVM.
-
#image_version ⇒ String
The version of the MicroVM image used to run this MicroVM.
-
#ingress_network_connectors ⇒ Array<String>
The list of ingress network connectors configured for the MicroVM.
-
#maximum_duration_in_seconds ⇒ Integer
The maximum duration in seconds that the MicroVM can exist before being terminated by the platform.
-
#microvm_id ⇒ String
The unique identifier of the MicroVM.
-
#started_at ⇒ Time
The timestamp when the MicroVM first started.
-
#state ⇒ String
The current lifecycle state of the MicroVM.
-
#state_reason ⇒ String
The reason for why the MicroVM is in the current state.
-
#terminated_at ⇒ Time
The timestamp when the MicroVM terminated.
Instance Attribute Details
#egress_network_connectors ⇒ Array<String>
The list of egress network connectors configured for the MicroVM.
803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 803 class GetMicrovmResponse < Struct.new( :microvm_id, :state, :endpoint, :image_arn, :image_version, :execution_role_arn, :idle_policy, :maximum_duration_in_seconds, :started_at, :terminated_at, :state_reason, :ingress_network_connectors, :egress_network_connectors) SENSITIVE = [] include Aws::Structure end |
#endpoint ⇒ String
The HTTPS endpoint URL for communicating with the MicroVM. Include a valid authentication token in the X-aws-proxy-auth header when sending requests.
803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 803 class GetMicrovmResponse < Struct.new( :microvm_id, :state, :endpoint, :image_arn, :image_version, :execution_role_arn, :idle_policy, :maximum_duration_in_seconds, :started_at, :terminated_at, :state_reason, :ingress_network_connectors, :egress_network_connectors) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The ARN of the IAM execution role assumed by the MicroVM.
803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 803 class GetMicrovmResponse < Struct.new( :microvm_id, :state, :endpoint, :image_arn, :image_version, :execution_role_arn, :idle_policy, :maximum_duration_in_seconds, :started_at, :terminated_at, :state_reason, :ingress_network_connectors, :egress_network_connectors) SENSITIVE = [] include Aws::Structure end |
#idle_policy ⇒ Types::IdlePolicy
The idle policy configuration of the MicroVM, controlling auto-suspend and auto-resume behavior.
803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 803 class GetMicrovmResponse < Struct.new( :microvm_id, :state, :endpoint, :image_arn, :image_version, :execution_role_arn, :idle_policy, :maximum_duration_in_seconds, :started_at, :terminated_at, :state_reason, :ingress_network_connectors, :egress_network_connectors) SENSITIVE = [] include Aws::Structure end |
#image_arn ⇒ String
The ARN of the MicroVM image used to run this MicroVM.
803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 803 class GetMicrovmResponse < Struct.new( :microvm_id, :state, :endpoint, :image_arn, :image_version, :execution_role_arn, :idle_policy, :maximum_duration_in_seconds, :started_at, :terminated_at, :state_reason, :ingress_network_connectors, :egress_network_connectors) SENSITIVE = [] include Aws::Structure end |
#image_version ⇒ String
The version of the MicroVM image used to run this MicroVM.
803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 803 class GetMicrovmResponse < Struct.new( :microvm_id, :state, :endpoint, :image_arn, :image_version, :execution_role_arn, :idle_policy, :maximum_duration_in_seconds, :started_at, :terminated_at, :state_reason, :ingress_network_connectors, :egress_network_connectors) SENSITIVE = [] include Aws::Structure end |
#ingress_network_connectors ⇒ Array<String>
The list of ingress network connectors configured for the MicroVM.
803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 803 class GetMicrovmResponse < Struct.new( :microvm_id, :state, :endpoint, :image_arn, :image_version, :execution_role_arn, :idle_policy, :maximum_duration_in_seconds, :started_at, :terminated_at, :state_reason, :ingress_network_connectors, :egress_network_connectors) SENSITIVE = [] include Aws::Structure end |
#maximum_duration_in_seconds ⇒ Integer
The maximum duration in seconds that the MicroVM can exist before being terminated by the platform.
803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 803 class GetMicrovmResponse < Struct.new( :microvm_id, :state, :endpoint, :image_arn, :image_version, :execution_role_arn, :idle_policy, :maximum_duration_in_seconds, :started_at, :terminated_at, :state_reason, :ingress_network_connectors, :egress_network_connectors) SENSITIVE = [] include Aws::Structure end |
#microvm_id ⇒ String
The unique identifier of the MicroVM.
803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 803 class GetMicrovmResponse < Struct.new( :microvm_id, :state, :endpoint, :image_arn, :image_version, :execution_role_arn, :idle_policy, :maximum_duration_in_seconds, :started_at, :terminated_at, :state_reason, :ingress_network_connectors, :egress_network_connectors) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The timestamp when the MicroVM first started.
803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 803 class GetMicrovmResponse < Struct.new( :microvm_id, :state, :endpoint, :image_arn, :image_version, :execution_role_arn, :idle_policy, :maximum_duration_in_seconds, :started_at, :terminated_at, :state_reason, :ingress_network_connectors, :egress_network_connectors) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current lifecycle state of the MicroVM.
803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 803 class GetMicrovmResponse < Struct.new( :microvm_id, :state, :endpoint, :image_arn, :image_version, :execution_role_arn, :idle_policy, :maximum_duration_in_seconds, :started_at, :terminated_at, :state_reason, :ingress_network_connectors, :egress_network_connectors) SENSITIVE = [] include Aws::Structure end |
#state_reason ⇒ String
The reason for why the MicroVM is in the current state.
803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 803 class GetMicrovmResponse < Struct.new( :microvm_id, :state, :endpoint, :image_arn, :image_version, :execution_role_arn, :idle_policy, :maximum_duration_in_seconds, :started_at, :terminated_at, :state_reason, :ingress_network_connectors, :egress_network_connectors) SENSITIVE = [] include Aws::Structure end |
#terminated_at ⇒ Time
The timestamp when the MicroVM terminated.
803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 803 class GetMicrovmResponse < Struct.new( :microvm_id, :state, :endpoint, :image_arn, :image_version, :execution_role_arn, :idle_policy, :maximum_duration_in_seconds, :started_at, :terminated_at, :state_reason, :ingress_network_connectors, :egress_network_connectors) SENSITIVE = [] include Aws::Structure end |