Class: Aws::LambdaMicrovms::Types::PortSpecification
- Inherits:
-
Struct
- Object
- Struct
- Aws::LambdaMicrovms::Types::PortSpecification
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-lambdamicrovms/types.rb
Overview
Note:
PortSpecification is a union - when making an API calls you must set exactly one of the members.
Specifies which ports are accessible on a MicroVM. Only one of the port specification options can be set.
Defined Under Namespace
Classes: AllPorts, Port, Range, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#all_ports ⇒ Types::Unit
Indicates that all ports are accessible.
-
#port ⇒ Integer
A single port number.
-
#range ⇒ Types::PortRange
A range of ports.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#all_ports ⇒ Types::Unit
Indicates that all ports are accessible.
1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1661 class PortSpecification < Struct.new( :port, :range, :all_ports, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Port < PortSpecification; end class Range < PortSpecification; end class AllPorts < PortSpecification; end class Unknown < PortSpecification; end end |
#port ⇒ Integer
A single port number.
1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1661 class PortSpecification < Struct.new( :port, :range, :all_ports, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Port < PortSpecification; end class Range < PortSpecification; end class AllPorts < PortSpecification; end class Unknown < PortSpecification; end end |
#range ⇒ Types::PortRange
A range of ports.
1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1661 class PortSpecification < Struct.new( :port, :range, :all_ports, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Port < PortSpecification; end class Range < PortSpecification; end class AllPorts < PortSpecification; end class Unknown < PortSpecification; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
1661 1662 1663 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1661 def unknown @unknown end |