Class: Aws::LambdaMicrovms::Types::RunMicrovmRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LambdaMicrovms::Types::RunMicrovmRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambdamicrovms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier you provide to ensure the idempotency of the request.
-
#egress_network_connectors ⇒ Array<String>
The list of egress network connectors to configure for the MicroVM.
-
#execution_role_arn ⇒ String
The ARN of the IAM role to be assumed by the MicroVM during execution.
-
#idle_policy ⇒ Types::IdlePolicy
Configuration to control auto-suspend and auto-resume behavior.
-
#image_identifier ⇒ String
The identifier (ARN or ID) of the MicroVM image to run.
-
#image_version ⇒ String
The version of the MicroVM image to run.
-
#ingress_network_connectors ⇒ Array<String>
The list of ingress network connectors to configure for the MicroVM.
-
#logging ⇒ Types::Logging
The logging configuration for this MicroVM instance.
-
#maximum_duration_in_seconds ⇒ Integer
The maximum duration in seconds that the MicroVM can exist before being terminated by the platform.
-
#run_hook_payload ⇒ String
Per-MicroVM initialization data delivered as the request body of the /run lifecycle hook.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier you provide to ensure the idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1800 class RunMicrovmRequest < Struct.new( :ingress_network_connectors, :egress_network_connectors, :image_identifier, :image_version, :execution_role_arn, :idle_policy, :logging, :run_hook_payload, :maximum_duration_in_seconds, :client_token) SENSITIVE = [] include Aws::Structure end |
#egress_network_connectors ⇒ Array<String>
The list of egress network connectors to configure for the MicroVM.
1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1800 class RunMicrovmRequest < Struct.new( :ingress_network_connectors, :egress_network_connectors, :image_identifier, :image_version, :execution_role_arn, :idle_policy, :logging, :run_hook_payload, :maximum_duration_in_seconds, :client_token) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The ARN of the IAM role to be assumed by the MicroVM during execution.
1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1800 class RunMicrovmRequest < Struct.new( :ingress_network_connectors, :egress_network_connectors, :image_identifier, :image_version, :execution_role_arn, :idle_policy, :logging, :run_hook_payload, :maximum_duration_in_seconds, :client_token) SENSITIVE = [] include Aws::Structure end |
#idle_policy ⇒ Types::IdlePolicy
Configuration to control auto-suspend and auto-resume behavior.
1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1800 class RunMicrovmRequest < Struct.new( :ingress_network_connectors, :egress_network_connectors, :image_identifier, :image_version, :execution_role_arn, :idle_policy, :logging, :run_hook_payload, :maximum_duration_in_seconds, :client_token) SENSITIVE = [] include Aws::Structure end |
#image_identifier ⇒ String
The identifier (ARN or ID) of the MicroVM image to run.
1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1800 class RunMicrovmRequest < Struct.new( :ingress_network_connectors, :egress_network_connectors, :image_identifier, :image_version, :execution_role_arn, :idle_policy, :logging, :run_hook_payload, :maximum_duration_in_seconds, :client_token) SENSITIVE = [] include Aws::Structure end |
#image_version ⇒ String
The version of the MicroVM image to run.
1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1800 class RunMicrovmRequest < Struct.new( :ingress_network_connectors, :egress_network_connectors, :image_identifier, :image_version, :execution_role_arn, :idle_policy, :logging, :run_hook_payload, :maximum_duration_in_seconds, :client_token) SENSITIVE = [] include Aws::Structure end |
#ingress_network_connectors ⇒ Array<String>
The list of ingress network connectors to configure for the MicroVM.
1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1800 class RunMicrovmRequest < Struct.new( :ingress_network_connectors, :egress_network_connectors, :image_identifier, :image_version, :execution_role_arn, :idle_policy, :logging, :run_hook_payload, :maximum_duration_in_seconds, :client_token) SENSITIVE = [] include Aws::Structure end |
#logging ⇒ Types::Logging
The logging configuration for this MicroVM instance. Specify {“logGroup”: “…”} to stream application logs to a custom CloudWatch log group, or {} to turn off logging.
1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1800 class RunMicrovmRequest < Struct.new( :ingress_network_connectors, :egress_network_connectors, :image_identifier, :image_version, :execution_role_arn, :idle_policy, :logging, :run_hook_payload, :maximum_duration_in_seconds, :client_token) SENSITIVE = [] include Aws::Structure end |
#maximum_duration_in_seconds ⇒ Integer
The maximum duration in seconds that the MicroVM can exist before being terminated by the platform. Valid range: 1–28,800 (8 hours).
1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1800 class RunMicrovmRequest < Struct.new( :ingress_network_connectors, :egress_network_connectors, :image_identifier, :image_version, :execution_role_arn, :idle_policy, :logging, :run_hook_payload, :maximum_duration_in_seconds, :client_token) SENSITIVE = [] include Aws::Structure end |
#run_hook_payload ⇒ String
Per-MicroVM initialization data delivered as the request body of the /run lifecycle hook. Use to pass tenant-specific configuration such as session IDs or secret references. Maximum: 16,384 bytes.
1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1800 class RunMicrovmRequest < Struct.new( :ingress_network_connectors, :egress_network_connectors, :image_identifier, :image_version, :execution_role_arn, :idle_policy, :logging, :run_hook_payload, :maximum_duration_in_seconds, :client_token) SENSITIVE = [] include Aws::Structure end |