Class: Aws::LambdaMicrovms::Types::RunMicrovmResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambdamicrovms/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#egress_network_connectorsArray<String>

The list of egress network connectors configured for the MicroVM.

Returns:

  • (Array<String>)


1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1871

class RunMicrovmResponse < Struct.new(
  :microvm_id,
  :state,
  :endpoint,
  :image_arn,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :maximum_duration_in_seconds,
  :started_at,
  :terminated_at,
  :state_reason,
  :ingress_network_connectors,
  :egress_network_connectors)
  SENSITIVE = []
  include Aws::Structure
end

#endpointString

The HTTPS endpoint URL for communicating with the MicroVM. Include a valid authentication token in the X-aws-proxy-auth header when sending requests.

Returns:

  • (String)


1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1871

class RunMicrovmResponse < Struct.new(
  :microvm_id,
  :state,
  :endpoint,
  :image_arn,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :maximum_duration_in_seconds,
  :started_at,
  :terminated_at,
  :state_reason,
  :ingress_network_connectors,
  :egress_network_connectors)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role_arnString

The ARN of the IAM execution role assumed by the MicroVM.

Returns:

  • (String)


1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1871

class RunMicrovmResponse < Struct.new(
  :microvm_id,
  :state,
  :endpoint,
  :image_arn,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :maximum_duration_in_seconds,
  :started_at,
  :terminated_at,
  :state_reason,
  :ingress_network_connectors,
  :egress_network_connectors)
  SENSITIVE = []
  include Aws::Structure
end

#idle_policyTypes::IdlePolicy

The idle policy configuration of the MicroVM.

Returns:



1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1871

class RunMicrovmResponse < Struct.new(
  :microvm_id,
  :state,
  :endpoint,
  :image_arn,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :maximum_duration_in_seconds,
  :started_at,
  :terminated_at,
  :state_reason,
  :ingress_network_connectors,
  :egress_network_connectors)
  SENSITIVE = []
  include Aws::Structure
end

#image_arnString

The ARN of the MicroVM image used to run this MicroVM.

Returns:

  • (String)


1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1871

class RunMicrovmResponse < Struct.new(
  :microvm_id,
  :state,
  :endpoint,
  :image_arn,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :maximum_duration_in_seconds,
  :started_at,
  :terminated_at,
  :state_reason,
  :ingress_network_connectors,
  :egress_network_connectors)
  SENSITIVE = []
  include Aws::Structure
end

#image_versionString

The version of the MicroVM image used to run this MicroVM.

Returns:

  • (String)


1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1871

class RunMicrovmResponse < Struct.new(
  :microvm_id,
  :state,
  :endpoint,
  :image_arn,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :maximum_duration_in_seconds,
  :started_at,
  :terminated_at,
  :state_reason,
  :ingress_network_connectors,
  :egress_network_connectors)
  SENSITIVE = []
  include Aws::Structure
end

#ingress_network_connectorsArray<String>

The list of ingress network connectors configured for the MicroVM.

Returns:

  • (Array<String>)


1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1871

class RunMicrovmResponse < Struct.new(
  :microvm_id,
  :state,
  :endpoint,
  :image_arn,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :maximum_duration_in_seconds,
  :started_at,
  :terminated_at,
  :state_reason,
  :ingress_network_connectors,
  :egress_network_connectors)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_duration_in_secondsInteger

The maximum duration in seconds that the MicroVM can exist.

Returns:

  • (Integer)


1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1871

class RunMicrovmResponse < Struct.new(
  :microvm_id,
  :state,
  :endpoint,
  :image_arn,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :maximum_duration_in_seconds,
  :started_at,
  :terminated_at,
  :state_reason,
  :ingress_network_connectors,
  :egress_network_connectors)
  SENSITIVE = []
  include Aws::Structure
end

#microvm_idString

The unique identifier of the MicroVM.

Returns:

  • (String)


1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1871

class RunMicrovmResponse < Struct.new(
  :microvm_id,
  :state,
  :endpoint,
  :image_arn,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :maximum_duration_in_seconds,
  :started_at,
  :terminated_at,
  :state_reason,
  :ingress_network_connectors,
  :egress_network_connectors)
  SENSITIVE = []
  include Aws::Structure
end

#started_atTime

The timestamp when the MicroVM first started.

Returns:

  • (Time)


1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1871

class RunMicrovmResponse < Struct.new(
  :microvm_id,
  :state,
  :endpoint,
  :image_arn,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :maximum_duration_in_seconds,
  :started_at,
  :terminated_at,
  :state_reason,
  :ingress_network_connectors,
  :egress_network_connectors)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The current lifecycle state of the MicroVM.

Returns:

  • (String)


1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1871

class RunMicrovmResponse < Struct.new(
  :microvm_id,
  :state,
  :endpoint,
  :image_arn,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :maximum_duration_in_seconds,
  :started_at,
  :terminated_at,
  :state_reason,
  :ingress_network_connectors,
  :egress_network_connectors)
  SENSITIVE = []
  include Aws::Structure
end

#state_reasonString

The reason for why the MicroVM is in the current state.

Returns:

  • (String)


1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1871

class RunMicrovmResponse < Struct.new(
  :microvm_id,
  :state,
  :endpoint,
  :image_arn,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :maximum_duration_in_seconds,
  :started_at,
  :terminated_at,
  :state_reason,
  :ingress_network_connectors,
  :egress_network_connectors)
  SENSITIVE = []
  include Aws::Structure
end

#terminated_atTime

The timestamp when the MicroVM terminated.

Returns:

  • (Time)


1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1871

class RunMicrovmResponse < Struct.new(
  :microvm_id,
  :state,
  :endpoint,
  :image_arn,
  :image_version,
  :execution_role_arn,
  :idle_policy,
  :maximum_duration_in_seconds,
  :started_at,
  :terminated_at,
  :state_reason,
  :ingress_network_connectors,
  :egress_network_connectors)
  SENSITIVE = []
  include Aws::Structure
end