Class: Aws::LambdaMicrovms::Types::RunMicrovmResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::LambdaMicrovms::Types::RunMicrovmResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambdamicrovms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#egress_network_connectors ⇒ Array<String>
The list of egress network connectors configured for the MicroVM.
-
#endpoint ⇒ String
The HTTPS endpoint URL for communicating with the MicroVM.
-
#execution_role_arn ⇒ String
The ARN of the IAM execution role assumed by the MicroVM.
-
#idle_policy ⇒ Types::IdlePolicy
The idle policy configuration of the MicroVM.
-
#image_arn ⇒ String
The ARN of the MicroVM image used to run this MicroVM.
-
#image_version ⇒ String
The version of the MicroVM image used to run this MicroVM.
-
#ingress_network_connectors ⇒ Array<String>
The list of ingress network connectors configured for the MicroVM.
-
#maximum_duration_in_seconds ⇒ Integer
The maximum duration in seconds that the MicroVM can exist.
-
#microvm_id ⇒ String
The unique identifier of the MicroVM.
-
#started_at ⇒ Time
The timestamp when the MicroVM first started.
-
#state ⇒ String
The current lifecycle state of the MicroVM.
-
#state_reason ⇒ String
The reason for why the MicroVM is in the current state.
-
#terminated_at ⇒ Time
The timestamp when the MicroVM terminated.
Instance Attribute Details
#egress_network_connectors ⇒ Array<String>
The list of egress network connectors configured for the MicroVM.
1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1871 class RunMicrovmResponse < Struct.new( :microvm_id, :state, :endpoint, :image_arn, :image_version, :execution_role_arn, :idle_policy, :maximum_duration_in_seconds, :started_at, :terminated_at, :state_reason, :ingress_network_connectors, :egress_network_connectors) SENSITIVE = [] include Aws::Structure end |
#endpoint ⇒ String
The HTTPS endpoint URL for communicating with the MicroVM. Include a valid authentication token in the X-aws-proxy-auth header when sending requests.
1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1871 class RunMicrovmResponse < Struct.new( :microvm_id, :state, :endpoint, :image_arn, :image_version, :execution_role_arn, :idle_policy, :maximum_duration_in_seconds, :started_at, :terminated_at, :state_reason, :ingress_network_connectors, :egress_network_connectors) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The ARN of the IAM execution role assumed by the MicroVM.
1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1871 class RunMicrovmResponse < Struct.new( :microvm_id, :state, :endpoint, :image_arn, :image_version, :execution_role_arn, :idle_policy, :maximum_duration_in_seconds, :started_at, :terminated_at, :state_reason, :ingress_network_connectors, :egress_network_connectors) SENSITIVE = [] include Aws::Structure end |
#idle_policy ⇒ Types::IdlePolicy
The idle policy configuration of the MicroVM.
1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1871 class RunMicrovmResponse < Struct.new( :microvm_id, :state, :endpoint, :image_arn, :image_version, :execution_role_arn, :idle_policy, :maximum_duration_in_seconds, :started_at, :terminated_at, :state_reason, :ingress_network_connectors, :egress_network_connectors) SENSITIVE = [] include Aws::Structure end |
#image_arn ⇒ String
The ARN of the MicroVM image used to run this MicroVM.
1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1871 class RunMicrovmResponse < Struct.new( :microvm_id, :state, :endpoint, :image_arn, :image_version, :execution_role_arn, :idle_policy, :maximum_duration_in_seconds, :started_at, :terminated_at, :state_reason, :ingress_network_connectors, :egress_network_connectors) SENSITIVE = [] include Aws::Structure end |
#image_version ⇒ String
The version of the MicroVM image used to run this MicroVM.
1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1871 class RunMicrovmResponse < Struct.new( :microvm_id, :state, :endpoint, :image_arn, :image_version, :execution_role_arn, :idle_policy, :maximum_duration_in_seconds, :started_at, :terminated_at, :state_reason, :ingress_network_connectors, :egress_network_connectors) SENSITIVE = [] include Aws::Structure end |
#ingress_network_connectors ⇒ Array<String>
The list of ingress network connectors configured for the MicroVM.
1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1871 class RunMicrovmResponse < Struct.new( :microvm_id, :state, :endpoint, :image_arn, :image_version, :execution_role_arn, :idle_policy, :maximum_duration_in_seconds, :started_at, :terminated_at, :state_reason, :ingress_network_connectors, :egress_network_connectors) SENSITIVE = [] include Aws::Structure end |
#maximum_duration_in_seconds ⇒ Integer
The maximum duration in seconds that the MicroVM can exist.
1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1871 class RunMicrovmResponse < Struct.new( :microvm_id, :state, :endpoint, :image_arn, :image_version, :execution_role_arn, :idle_policy, :maximum_duration_in_seconds, :started_at, :terminated_at, :state_reason, :ingress_network_connectors, :egress_network_connectors) SENSITIVE = [] include Aws::Structure end |
#microvm_id ⇒ String
The unique identifier of the MicroVM.
1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1871 class RunMicrovmResponse < Struct.new( :microvm_id, :state, :endpoint, :image_arn, :image_version, :execution_role_arn, :idle_policy, :maximum_duration_in_seconds, :started_at, :terminated_at, :state_reason, :ingress_network_connectors, :egress_network_connectors) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The timestamp when the MicroVM first started.
1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1871 class RunMicrovmResponse < Struct.new( :microvm_id, :state, :endpoint, :image_arn, :image_version, :execution_role_arn, :idle_policy, :maximum_duration_in_seconds, :started_at, :terminated_at, :state_reason, :ingress_network_connectors, :egress_network_connectors) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current lifecycle state of the MicroVM.
1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1871 class RunMicrovmResponse < Struct.new( :microvm_id, :state, :endpoint, :image_arn, :image_version, :execution_role_arn, :idle_policy, :maximum_duration_in_seconds, :started_at, :terminated_at, :state_reason, :ingress_network_connectors, :egress_network_connectors) SENSITIVE = [] include Aws::Structure end |
#state_reason ⇒ String
The reason for why the MicroVM is in the current state.
1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1871 class RunMicrovmResponse < Struct.new( :microvm_id, :state, :endpoint, :image_arn, :image_version, :execution_role_arn, :idle_policy, :maximum_duration_in_seconds, :started_at, :terminated_at, :state_reason, :ingress_network_connectors, :egress_network_connectors) SENSITIVE = [] include Aws::Structure end |
#terminated_at ⇒ Time
The timestamp when the MicroVM terminated.
1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1871 class RunMicrovmResponse < Struct.new( :microvm_id, :state, :endpoint, :image_arn, :image_version, :execution_role_arn, :idle_policy, :maximum_duration_in_seconds, :started_at, :terminated_at, :state_reason, :ingress_network_connectors, :egress_network_connectors) SENSITIVE = [] include Aws::Structure end |