Class: Aws::LambdaMicrovms::Types::ServiceQuotaExceededException
- Inherits:
-
Struct
- Object
- Struct
- Aws::LambdaMicrovms::Types::ServiceQuotaExceededException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambdamicrovms/types.rb
Overview
You have exceeded a service quota for Lambda MicroVMs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #message ⇒ String
-
#quota_code ⇒ String
The quota code of the exceeded service quota.
-
#resource_id ⇒ String
The identifier of the resource that exceeded the quota.
-
#resource_type ⇒ String
The type of the resource that exceeded the quota.
-
#service_code ⇒ String
The service code of the exceeded service quota.
Instance Attribute Details
#message ⇒ String
1930 1931 1932 1933 1934 1935 1936 1937 1938 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1930 class ServiceQuotaExceededException < Struct.new( :message, :resource_id, :resource_type, :service_code, :quota_code) SENSITIVE = [] include Aws::Structure end |
#quota_code ⇒ String
The quota code of the exceeded service quota.
1930 1931 1932 1933 1934 1935 1936 1937 1938 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1930 class ServiceQuotaExceededException < Struct.new( :message, :resource_id, :resource_type, :service_code, :quota_code) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
The identifier of the resource that exceeded the quota.
1930 1931 1932 1933 1934 1935 1936 1937 1938 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1930 class ServiceQuotaExceededException < Struct.new( :message, :resource_id, :resource_type, :service_code, :quota_code) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of the resource that exceeded the quota.
1930 1931 1932 1933 1934 1935 1936 1937 1938 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1930 class ServiceQuotaExceededException < Struct.new( :message, :resource_id, :resource_type, :service_code, :quota_code) SENSITIVE = [] include Aws::Structure end |
#service_code ⇒ String
The service code of the exceeded service quota.
1930 1931 1932 1933 1934 1935 1936 1937 1938 |
# File 'lib/aws-sdk-lambdamicrovms/types.rb', line 1930 class ServiceQuotaExceededException < Struct.new( :message, :resource_id, :resource_type, :service_code, :quota_code) SENSITIVE = [] include Aws::Structure end |